pub struct ScoreOperator {
pub scorer: Arc<dyn Scorer>,
pub source: Arc<dyn Operator>,
pub query_terms: Vec<String>,
pub field: FieldName,
}Expand description
Score_q: apply a Scorer to every entry of a source posting list.
IDF and per-document length are hoisted out of the inner loop.
Fields
scorer: Arc<dyn Scorer>source: Arc<dyn Operator>query_terms: Vec<String>field: FieldNameImplementations